@@ -18,11 +18,16 @@ class DKConnection():
         self.token = r.text
         self.headers =  {'content-type': 'application/json', 'authorization': 'bearer ' + self.token}
 
-    def createOrder(self, kitchen, recipe, variation, overrides={}):
+    def createOrder(self, kitchen, recipe, variation, overrides={}, retries=0):
         headers = {'content-type': 'application/json', 'authorization': 'bearer ' + self.token}
         url = 'https://%s/v2/order/create/%s/%s/%s' % (self.hostname, kitchen, recipe, variation)
         payload = {'parameters': overrides, "schedule" : "now"}
-        return requests.put(url, headers=headers, data=json.dumps(payload))
+        response = requests.put(url, headers=headers, data=json.dumps(payload))
+        attempts = 1
+        while attempts <= retries and respnse != 200:
+            response = requests.put(url, headers=headers, data=json.dumps(payload))
+            attemps += 1
+        return response
 
     def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=50000, test_level=""):
         response = self.createOrder(kitchen, recipe, variation, overrides=overrides)
